:orphan:

.. _glossary:

Glossary
========

.. glossary::

  Git
    `Git <https://git-scm.com/>`_ is a distributed software version 
    control system.

  Mercurial
    `Mercurial <https://www.mercurial-scm.org/>`_ is a distributed 
    software version control system.

  Sphinx
    The documentation for this package is maintained using
    `Sphinx <https://www.sphinx-doc.org/>`_, a tool to create documentation
    in many formats based on reStructuredText files.

  Subversion
    `Subversion <https://subversion.apache.org/>`_ is a software version 
    control system.

  virtual environment
    The `Python venv module <https://docs.python.org/3/library/venv.html>`_
    is used to create lightweight “virtual environments”, each with their
    own independent set of Python packages installed in their site
    directories. A virtual environment is created on top of an existing
    Python installation, known as the virtual environment’s “base” Python,
    and may optionally be isolated from the packages in the base environment,
    so only those explicitly installed in the virtual environment are
    available.

  zc.buildout
    `zc.buildout <http://buildout.org>`_ is a Python-based build system 
    for creating, assembling and deploying applications.
